#include <kdialog.h>
#include <klocale.h>
/****************************************************************************
** Form implementation generated from reading ui file './srkprefdialogbase.ui'
**
** Created: wo sep 6 18:04:20 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.6   edited Aug 31 2005 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "srkprefdialogbase.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qtabwidget.h>
#include <qwidget.h>
#include <qbuttongroup.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <klineedit.h>
#include <kactivelabel.h>
#include <qradiobutton.h>
#include <krestrictedline.h>
#include <qspinbox.h>
#include <kcolorbutton.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>

/*
 *  Constructs a SRKPrefDialogBase as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
SRKPrefDialogBase::SRKPrefDialogBase( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "SRKPrefDialogBase" );
    setSizeGripEnabled( TRUE );
    SRKPrefDialogBaseLayout = new QGridLayout( this, 1, 1, 11, 6, "SRKPrefDialogBaseLayout"); 

    layout2 = new QHBoxLayout( 0, 0, 6, "layout2"); 

    buttonOk = new QPushButton( this, "buttonOk" );
    buttonOk->setAutoDefault( TRUE );
    buttonOk->setDefault( TRUE );
    layout2->addWidget( buttonOk );

    buttonCancel = new QPushButton( this, "buttonCancel" );
    buttonCancel->setAutoDefault( TRUE );
    layout2->addWidget( buttonCancel );
    spacer2 = new QSpacerItem( 400, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout2->addItem( spacer2 );

    SRKPrefDialogBaseLayout->addLayout( layout2, 1, 0 );

    tabPanel = new QTabWidget( this, "tabPanel" );

    Widget2 = new QWidget( tabPanel, "Widget2" );
    Widget2Layout = new QGridLayout( Widget2, 1, 1, 11, 6, "Widget2Layout"); 

    networkLintorialsGrp = new QButtonGroup( Widget2, "networkLintorialsGrp" );
    networkLintorialsGrp->setColumnLayout(0, Qt::Vertical );
    networkLintorialsGrp->layout()->setSpacing( 6 );
    networkLintorialsGrp->layout()->setMargin( 11 );
    networkLintorialsGrpLayout = new QGridLayout( networkLintorialsGrp->layout() );
    networkLintorialsGrpLayout->setAlignment( Qt::AlignTop );

    loginGrp = new QGroupBox( networkLintorialsGrp, "loginGrp" );
    loginGrp->setEnabled( TRUE );
    loginGrp->setColumnLayout(0, Qt::Vertical );
    loginGrp->layout()->setSpacing( 6 );
    loginGrp->layout()->setMargin( 11 );
    loginGrpLayout = new QGridLayout( loginGrp->layout() );
    loginGrpLayout->setAlignment( Qt::AlignTop );

    layout6 = new QGridLayout( 0, 1, 1, 0, 6, "layout6"); 

    textLabel3_2 = new QLabel( loginGrp, "textLabel3_2" );
    textLabel3_2->setEnabled( TRUE );

    layout6->addWidget( textLabel3_2, 1, 0 );

    textLabel3 = new QLabel( loginGrp, "textLabel3" );
    textLabel3->setEnabled( TRUE );

    layout6->addWidget( textLabel3, 0, 0 );

    networkLoginPasswordText = new KLineEdit( loginGrp, "networkLoginPasswordText" );
    networkLoginPasswordText->setEnabled( TRUE );
    networkLoginPasswordText->setEchoMode( KLineEdit::Password );

    layout6->addWidget( networkLoginPasswordText, 1, 1 );

    networkLoginUsernameText = new KLineEdit( loginGrp, "networkLoginUsernameText" );
    networkLoginUsernameText->setEnabled( TRUE );

    layout6->addWidget( networkLoginUsernameText, 0, 1 );

    loginGrpLayout->addLayout( layout6, 1, 0 );
    spacer14 = new QSpacerItem( 70, 20, QSizePolicy::Preferred, QSizePolicy::Minimum );
    loginGrpLayout->addItem( spacer14, 1, 1 );

    loginInfoLbl = new KActiveLabel( loginGrp, "loginInfoLbl" );

    loginGrpLayout->addMultiCellWidget( loginInfoLbl, 0, 0, 0, 1 );

    networkLintorialsGrpLayout->addWidget( loginGrp, 2, 0 );

    layout6_2 = new QHBoxLayout( 0, 0, 6, "layout6_2"); 

    networkWebserviceLbl = new QLabel( networkLintorialsGrp, "networkWebserviceLbl" );
    networkWebserviceLbl->setEnabled( TRUE );
    layout6_2->addWidget( networkWebserviceLbl );

    networkWebserviceText = new KLineEdit( networkLintorialsGrp, "networkWebserviceText" );
    networkWebserviceText->setEnabled( TRUE );
    layout6_2->addWidget( networkWebserviceText );

    networkLintorialsGrpLayout->addLayout( layout6_2, 0, 0 );

    layout11 = new QHBoxLayout( 0, 0, 6, "layout11"); 
    spacer16 = new QSpacerItem( 21, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout11->addItem( spacer16 );

    networkWebserviceLbl_2 = new QLabel( networkLintorialsGrp, "networkWebserviceLbl_2" );
    networkWebserviceLbl_2->setEnabled( TRUE );
    networkWebserviceLbl_2->setPaletteForegroundColor( QColor( 255, 0, 0 ) );
    layout11->addWidget( networkWebserviceLbl_2 );
    spacer16_2 = new QSpacerItem( 210, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout11->addItem( spacer16_2 );

    networkLintorialsGrpLayout->addLayout( layout11, 1, 0 );

    Widget2Layout->addWidget( networkLintorialsGrp, 0, 0 );
    tabPanel->insertTab( Widget2, QString::fromLatin1("") );

    Widget3 = new QWidget( tabPanel, "Widget3" );
    Widget3Layout = new QGridLayout( Widget3, 1, 1, 11, 6, "Widget3Layout"); 

    vncServerGrp = new QButtonGroup( Widget3, "vncServerGrp" );
    vncServerGrp->setColumnLayout(0, Qt::Vertical );
    vncServerGrp->layout()->setSpacing( 6 );
    vncServerGrp->layout()->setMargin( 11 );
    vncServerGrpLayout = new QGridLayout( vncServerGrp->layout() );
    vncServerGrpLayout->setAlignment( Qt::AlignTop );

    layout6_3 = new QHBoxLayout( 0, 0, 6, "layout6_3"); 

    vncServerLocLbl = new QLabel( vncServerGrp, "vncServerLocLbl" );
    vncServerLocLbl->setEnabled( TRUE );
    layout6_3->addWidget( vncServerLocLbl );

    vncServerLocText = new KLineEdit( vncServerGrp, "vncServerLocText" );
    vncServerLocText->setEnabled( TRUE );
    layout6_3->addWidget( vncServerLocText );

    vncServerGrpLayout->addLayout( layout6_3, 0, 0 );

    layout5 = new QGridLayout( 0, 1, 1, 0, 6, "layout5"); 

    vncServerOpt1 = new QRadioButton( vncServerGrp, "vncServerOpt1" );
    vncServerGrp->insert( vncServerOpt1, -1 );

    layout5->addMultiCellWidget( vncServerOpt1, 0, 0, 0, 5 );

    vncServerResXLbl = new QLabel( vncServerGrp, "vncServerResXLbl" );
    vncServerResXLbl->setEnabled( FALSE );

    layout5->addWidget( vncServerResXLbl, 2, 3 );

    vncServerXResText = new KRestrictedLine( vncServerGrp, "vncServerXResText" );
    vncServerXResText->setEnabled( FALSE );

    layout5->addWidget( vncServerXResText, 2, 2 );

    vncServerDispLbl = new QLabel( vncServerGrp, "vncServerDispLbl" );
    vncServerDispLbl->setEnabled( FALSE );

    layout5->addWidget( vncServerDispLbl, 1, 1 );
    spacer5 = new QSpacerItem( 26, 10, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5->addItem( spacer5, 1, 0 );

    vncServerResLbl = new QLabel( vncServerGrp, "vncServerResLbl" );
    vncServerResLbl->setEnabled( FALSE );

    layout5->addWidget( vncServerResLbl, 2, 1 );
    spacer7 = new QSpacerItem( 136, 10, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5->addMultiCell( spacer7, 1, 1, 3, 5 );

    vncServerYResText = new KRestrictedLine( vncServerGrp, "vncServerYResText" );
    vncServerYResText->setEnabled( FALSE );

    layout5->addWidget( vncServerYResText, 2, 4 );
    spacer8 = new QSpacerItem( 31, 10, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5->addItem( spacer8, 2, 5 );

    vncServerDispText1 = new KRestrictedLine( vncServerGrp, "vncServerDispText1" );
    vncServerDispText1->setEnabled( FALSE );

    layout5->addWidget( vncServerDispText1, 1, 2 );
    spacer6 = new QSpacerItem( 26, 10, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout5->addItem( spacer6, 2, 0 );

    vncServerGrpLayout->addLayout( layout5, 1, 0 );

    layout4 = new QGridLayout( 0, 1, 1, 0, 6, "layout4"); 

    vncServerDispLbl2 = new QLabel( vncServerGrp, "vncServerDispLbl2" );
    vncServerDispLbl2->setEnabled( TRUE );

    layout4->addWidget( vncServerDispLbl2, 2, 1 );
    spacer3 = new QSpacerItem( 25, 16, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout4->addItem( spacer3, 1, 0 );
    spacer2_2 = new QSpacerItem( 220, 10, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout4->addItem( spacer2_2, 2, 3 );

    vncServerOpt2 = new QRadioButton( vncServerGrp, "vncServerOpt2" );
    vncServerOpt2->setChecked( TRUE );
    vncServerGrp->insert( vncServerOpt2, -1 );

    layout4->addMultiCellWidget( vncServerOpt2, 0, 0, 0, 2 );

    vncServerDispText2 = new KRestrictedLine( vncServerGrp, "vncServerDispText2" );
    vncServerDispText2->setEnabled( TRUE );

    layout4->addWidget( vncServerDispText2, 2, 2 );

    vncServerHostText = new KLineEdit( vncServerGrp, "vncServerHostText" );
    vncServerHostText->setEnabled( TRUE );

    layout4->addMultiCellWidget( vncServerHostText, 1, 1, 2, 3 );
    spacer4 = new QSpacerItem( 26, 10, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout4->addItem( spacer4, 2, 0 );

    vncServerHostLbl = new QLabel( vncServerGrp, "vncServerHostLbl" );
    vncServerHostLbl->setEnabled( TRUE );

    layout4->addWidget( vncServerHostLbl, 1, 1 );

    vncServerGrpLayout->addLayout( layout4, 2, 0 );

    Widget3Layout->addWidget( vncServerGrp, 0, 0 );
    tabPanel->insertTab( Widget3, QString::fromLatin1("") );

    TabPage = new QWidget( tabPanel, "TabPage" );
    TabPageLayout = new QGridLayout( TabPage, 1, 1, 11, 6, "TabPageLayout"); 
    spacer15 = new QSpacerItem( 20, 170, QSizePolicy::Minimum, QSizePolicy::Expanding );
    TabPageLayout->addItem( spacer15, 1, 0 );

    layout14 = new QGridLayout( 0, 1, 1, 0, 6, "layout14"); 

    pathIsdExportText = new KLineEdit( TabPage, "pathIsdExportText" );
    pathIsdExportText->setEnabled( TRUE );

    layout14->addWidget( pathIsdExportText, 1, 2 );
    spacer13 = new QSpacerItem( 20, 20, QSizePolicy::Preferred, QSizePolicy::Minimum );
    layout14->addItem( spacer13, 0, 1 );

    pathIsdExportLbl = new QLabel( TabPage, "pathIsdExportLbl" );
    pathIsdExportLbl->setEnabled( TRUE );

    layout14->addWidget( pathIsdExportLbl, 1, 0 );

    pathIsdViewerText = new KLineEdit( TabPage, "pathIsdViewerText" );
    pathIsdViewerText->setEnabled( TRUE );

    layout14->addWidget( pathIsdViewerText, 0, 2 );
    spacer13_2 = new QSpacerItem( 20, 20, QSizePolicy::Preferred, QSizePolicy::Minimum );
    layout14->addItem( spacer13_2, 1, 1 );

    pathIsdViewerLbl = new QLabel( TabPage, "pathIsdViewerLbl" );
    pathIsdViewerLbl->setEnabled( TRUE );

    layout14->addWidget( pathIsdViewerLbl, 0, 0 );

    TabPageLayout->addLayout( layout14, 0, 0 );
    tabPanel->insertTab( TabPage, QString::fromLatin1("") );

    TabPage_2 = new QWidget( tabPanel, "TabPage_2" );
    TabPageLayout_2 = new QGridLayout( TabPage_2, 1, 1, 11, 6, "TabPageLayout_2"); 
    spacer15_2 = new QSpacerItem( 20, 20, QSizePolicy::Minimum, QSizePolicy::Expanding );
    TabPageLayout_2->addItem( spacer15_2, 1, 0 );

    buttonGroup3 = new QButtonGroup( TabPage_2, "buttonGroup3" );
    buttonGroup3->setColumnLayout(0, Qt::Vertical );
    buttonGroup3->layout()->setSpacing( 6 );
    buttonGroup3->layout()->setMargin( 11 );
    buttonGroup3Layout = new QGridLayout( buttonGroup3->layout() );
    buttonGroup3Layout->setAlignment( Qt::AlignTop );

    layout25 = new QVBoxLayout( 0, 0, 6, "layout25"); 

    layout11_2 = new QHBoxLayout( 0, 0, 6, "layout11_2"); 

    pathIsdViewerLbl_2 = new QLabel( buttonGroup3, "pathIsdViewerLbl_2" );
    pathIsdViewerLbl_2->setEnabled( TRUE );
    layout11_2->addWidget( pathIsdViewerLbl_2 );
    spacer13_3 = new QSpacerItem( 74, 20, QSizePolicy::Preferred, QSizePolicy::Minimum );
    layout11_2->addItem( spacer13_3 );

    defaultCommentDuration = new QSpinBox( buttonGroup3, "defaultCommentDuration" );
    defaultCommentDuration->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, defaultCommentDuration->sizePolicy().hasHeightForWidth() ) );
    defaultCommentDuration->setMaxValue( 400000000 );
    defaultCommentDuration->setValue( 3000 );
    layout11_2->addWidget( defaultCommentDuration );
    layout25->addLayout( layout11_2 );

    layout11_2_2 = new QHBoxLayout( 0, 0, 6, "layout11_2_2"); 

    pathIsdViewerLbl_2_2 = new QLabel( buttonGroup3, "pathIsdViewerLbl_2_2" );
    pathIsdViewerLbl_2_2->setEnabled( TRUE );
    layout11_2_2->addWidget( pathIsdViewerLbl_2_2 );
    spacer13_3_3 = new QSpacerItem( 74, 20, QSizePolicy::Preferred, QSizePolicy::Minimum );
    layout11_2_2->addItem( spacer13_3_3 );

    defaultCommentOpacity = new QSpinBox( buttonGroup3, "defaultCommentOpacity" );
    defaultCommentOpacity->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, defaultCommentOpacity->sizePolicy().hasHeightForWidth() ) );
    defaultCommentOpacity->setMaxValue( 400000000 );
    defaultCommentOpacity->setValue( 50 );
    layout11_2_2->addWidget( defaultCommentOpacity );
    layout25->addLayout( layout11_2_2 );

    layout11_3 = new QHBoxLayout( 0, 0, 6, "layout11_3"); 

    pathIsdViewerLbl_2_3 = new QLabel( buttonGroup3, "pathIsdViewerLbl_2_3" );
    pathIsdViewerLbl_2_3->setEnabled( TRUE );
    layout11_3->addWidget( pathIsdViewerLbl_2_3 );
    spacer13_3_4 = new QSpacerItem( 74, 20, QSizePolicy::Preferred, QSizePolicy::Minimum );
    layout11_3->addItem( spacer13_3_4 );

    defaultCommentWidth = new QSpinBox( buttonGroup3, "defaultCommentWidth" );
    defaultCommentWidth->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, defaultCommentWidth->sizePolicy().hasHeightForWidth() ) );
    defaultCommentWidth->setMaxValue( 400000000 );
    defaultCommentWidth->setValue( 300 );
    layout11_3->addWidget( defaultCommentWidth );
    layout25->addLayout( layout11_3 );

    layout11_4 = new QHBoxLayout( 0, 0, 6, "layout11_4"); 

    pathIsdViewerLbl_2_4 = new QLabel( buttonGroup3, "pathIsdViewerLbl_2_4" );
    pathIsdViewerLbl_2_4->setEnabled( TRUE );
    layout11_4->addWidget( pathIsdViewerLbl_2_4 );
    spacer13_3_5 = new QSpacerItem( 74, 20, QSizePolicy::Preferred, QSizePolicy::Minimum );
    layout11_4->addItem( spacer13_3_5 );

    defaultCommentHeight = new QSpinBox( buttonGroup3, "defaultCommentHeight" );
    defaultCommentHeight->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, defaultCommentHeight->sizePolicy().hasHeightForWidth() ) );
    defaultCommentHeight->setMaxValue( 400000000 );
    defaultCommentHeight->setValue( 200 );
    layout11_4->addWidget( defaultCommentHeight );
    layout25->addLayout( layout11_4 );

    layout7 = new QHBoxLayout( 0, 0, 6, "layout7"); 

    textLabel1_2 = new QLabel( buttonGroup3, "textLabel1_2" );
    layout7->addWidget( textLabel1_2 );
    spacer3_2 = new QSpacerItem( 41, 10, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout7->addItem( spacer3_2 );

    defaultCommentFillColor = new KColorButton( buttonGroup3, "defaultCommentFillColor" );
    defaultCommentFillColor->setColor( QColor( 255, 255, 255 ) );
    layout7->addWidget( defaultCommentFillColor );
    layout25->addLayout( layout7 );

    layout7_2 = new QHBoxLayout( 0, 0, 6, "layout7_2"); 

    textLabel1_2_2 = new QLabel( buttonGroup3, "textLabel1_2_2" );
    layout7_2->addWidget( textLabel1_2_2 );
    spacer3_2_2 = new QSpacerItem( 41, 10, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout7_2->addItem( spacer3_2_2 );

    defaultCommentTextColor = new KColorButton( buttonGroup3, "defaultCommentTextColor" );
    defaultCommentTextColor->setColor( QColor( 0, 0, 0 ) );
    layout7_2->addWidget( defaultCommentTextColor );
    layout25->addLayout( layout7_2 );

    buttonGroup3Layout->addLayout( layout25, 0, 0 );
    spacer36 = new QSpacerItem( 110, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    buttonGroup3Layout->addItem( spacer36, 0, 1 );

    TabPageLayout_2->addWidget( buttonGroup3, 0, 0 );
    tabPanel->insertTab( TabPage_2, QString::fromLatin1("") );

    SRKPrefDialogBaseLayout->addWidget( tabPanel, 0, 0 );
    languageChange();
    resize( QSize(554, 351).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // signals and slots connections
    connect( buttonOk, SIGNAL( clicked() ), this, SLOT( accept() ) );
    connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
    connect( vncServerOpt1, SIGNAL( toggled(bool) ), vncServerDispLbl, SLOT( setEnabled(bool) ) );
    connect( vncServerOpt1, SIGNAL( toggled(bool) ), vncServerDispText1, SLOT( setEnabled(bool) ) );
    connect( vncServerOpt1, SIGNAL( toggled(bool) ), vncServerResLbl, SLOT( setEnabled(bool) ) );
    connect( vncServerOpt1, SIGNAL( toggled(bool) ), vncServerXResText, SLOT( setEnabled(bool) ) );
    connect( vncServerOpt1, SIGNAL( toggled(bool) ), vncServerResXLbl, SLOT( setEnabled(bool) ) );
    connect( vncServerOpt1, SIGNAL( toggled(bool) ), vncServerYResText, SLOT( setEnabled(bool) ) );
    connect( vncServerOpt2, SIGNAL( toggled(bool) ), vncServerHostLbl, SLOT( setEnabled(bool) ) );
    connect( vncServerOpt2, SIGNAL( toggled(bool) ), vncServerHostText, SLOT( setEnabled(bool) ) );
    connect( vncServerOpt2, SIGNAL( toggled(bool) ), vncServerDispLbl2, SLOT( setEnabled(bool) ) );
    connect( vncServerOpt2, SIGNAL( toggled(bool) ), vncServerDispText2, SLOT( setEnabled(bool) ) );

    // tab order
    setTabOrder( tabPanel, networkWebserviceText );
    setTabOrder( networkWebserviceText, loginInfoLbl );
    setTabOrder( loginInfoLbl, networkLoginUsernameText );
    setTabOrder( networkLoginUsernameText, networkLoginPasswordText );
    setTabOrder( networkLoginPasswordText, vncServerLocText );
    setTabOrder( vncServerLocText, vncServerOpt1 );
    setTabOrder( vncServerOpt1, vncServerDispText1 );
    setTabOrder( vncServerDispText1, vncServerXResText );
    setTabOrder( vncServerXResText, vncServerYResText );
    setTabOrder( vncServerYResText, vncServerOpt2 );
    setTabOrder( vncServerOpt2, vncServerHostText );
    setTabOrder( vncServerHostText, vncServerDispText2 );
    setTabOrder( vncServerDispText2, pathIsdViewerText );
    setTabOrder( pathIsdViewerText, pathIsdExportText );
    setTabOrder( pathIsdExportText, defaultCommentDuration );
    setTabOrder( defaultCommentDuration, defaultCommentOpacity );
    setTabOrder( defaultCommentOpacity, defaultCommentWidth );
    setTabOrder( defaultCommentWidth, defaultCommentHeight );
    setTabOrder( defaultCommentHeight, defaultCommentFillColor );
    setTabOrder( defaultCommentFillColor, defaultCommentTextColor );
    setTabOrder( defaultCommentTextColor, buttonOk );
    setTabOrder( buttonOk, buttonCancel );
}

/*
 *  Destroys the object and frees any allocated resources
 */
SRKPrefDialogBase::~SRKPrefDialogBase()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void SRKPrefDialogBase::languageChange()
{
    setCaption( tr2i18n( "Preferences" ) );
    buttonOk->setText( tr2i18n( "&OK" ) );
    buttonOk->setAccel( QKeySequence( QString::null ) );
    buttonCancel->setText( tr2i18n( "&Cancel" ) );
    buttonCancel->setAccel( QKeySequence( tr2i18n( "Alt+C" ) ) );
    networkLintorialsGrp->setTitle( tr2i18n( "captorials.com" ) );
    loginGrp->setTitle( tr2i18n( "Login information" ) );
    textLabel3_2->setText( tr2i18n( "password" ) );
    textLabel3->setText( tr2i18n( "username" ) );
    loginInfoLbl->setText( tr2i18n( "Please provide your account-information.<br>\n"
"If you don't have an account, you can acquire one at <a href=\"http://www.lintorials.com\">http://www.captorials.com</a>" ) );
    networkWebserviceLbl->setText( tr2i18n( "webservice url" ) );
    networkWebserviceText->setText( QString::null );
    networkWebserviceLbl_2->setText( tr2i18n( "Note: leave this empty if unsure." ) );
    tabPanel->changeTab( Widget2, tr2i18n( "&Network" ) );
    vncServerGrp->setTitle( tr2i18n( "server" ) );
    vncServerLocLbl->setText( tr2i18n( "vncserver location" ) );
    vncServerLocText->setText( QString::null );
    vncServerOpt1->setText( tr2i18n( "Launch/kill vncserver on localhost at startup/e&xit" ) );
    vncServerOpt1->setAccel( QKeySequence( tr2i18n( "Alt+X" ) ) );
    vncServerResXLbl->setText( tr2i18n( "X" ) );
    vncServerXResText->setText( QString::null );
    vncServerXResText->setValidChars( tr2i18n( "0123456789" ) );
    vncServerDispLbl->setText( tr2i18n( "display" ) );
    vncServerResLbl->setText( tr2i18n( "resolution" ) );
    vncServerYResText->setText( QString::null );
    vncServerYResText->setValidChars( tr2i18n( "0123456789" ) );
    vncServerDispText1->setText( QString::null );
    vncServerDispText1->setValidChars( tr2i18n( "0123456789" ) );
    vncServerDispLbl2->setText( tr2i18n( "display" ) );
    vncServerOpt2->setText( tr2i18n( "Use vnc server &at:" ) );
    vncServerOpt2->setAccel( QKeySequence( tr2i18n( "Alt+A" ) ) );
    vncServerDispText2->setText( QString::null );
    vncServerDispText2->setValidChars( tr2i18n( "0123456789." ) );
    vncServerHostText->setText( QString::null );
    vncServerHostLbl->setText( tr2i18n( "host" ) );
    tabPanel->changeTab( Widget3, tr2i18n( "V&NC" ) );
    pathIsdExportText->setText( QString::null );
    pathIsdExportLbl->setText( tr2i18n( "isdexport location" ) );
    pathIsdViewerText->setText( QString::null );
    pathIsdViewerLbl->setText( tr2i18n( "isdvncviewer location" ) );
    tabPanel->changeTab( TabPage, tr2i18n( "Paths" ) );
    buttonGroup3->setTitle( tr2i18n( "commentboxes" ) );
    pathIsdViewerLbl_2->setText( tr2i18n( "default duration (millis)" ) );
    pathIsdViewerLbl_2_2->setText( tr2i18n( "default opacity (percentage)" ) );
    pathIsdViewerLbl_2_3->setText( tr2i18n( "default width" ) );
    pathIsdViewerLbl_2_4->setText( tr2i18n( "default height" ) );
    textLabel1_2->setText( tr2i18n( "default fill color hint" ) );
    defaultCommentFillColor->setText( QString::null );
    textLabel1_2_2->setText( tr2i18n( "default text color hint" ) );
    defaultCommentTextColor->setText( QString::null );
    tabPanel->changeTab( TabPage_2, tr2i18n( "Defaults" ) );
}

#include "srkprefdialogbase.moc"
