/***************************************************************************
 *   Copyright (C) 2006 by Bram Biesbrouck                                 *
 *   b@beligum.org                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.             *
 ***************************************************************************/

#ifndef SRKEXPORTER_H
#define SRKEXPORTER_H

/**
 *
 * @author Bram Biesbrouck <b@beligum.org>
 */

#include <string>
#include <qthread.h>

#include "srkmainview.h"

using namespace std;

class ISDRecording;
class QString;

class SRKExporter : public QThread
{
 public:
    SRKExporter(ISDRecording* recording, QString& fileName, QString& lang, SRKMainView::SRKExportProgressCallback* callback);
    
    virtual ~SRKExporter();

    virtual void run();

 protected:
    ISDRecording* recording;
    QString fileName;
    QString lang;
    SRKMainView::SRKExportProgressCallback* callback;
};

#endif
