/****************************************************************************
** Form interface generated from reading ui file './srkcommentpropertiesdialogbase.ui'
**
** Created: wo sep 6 18:03:30 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.6   edited Aug 31 2005 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SRKCOMMENTPROPERTIESDIALOGBASE_H
#define SRKCOMMENTPROPERTIESDIALOGBASE_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QPushButton;
class QGroupBox;
class QLabel;
class QSpinBox;
class QCheckBox;
class KColorButton;

class SRKCommentPropertiesDialogBase : public QDialog
{
    Q_OBJECT

public:
    SRKCommentPropertiesDialogBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~SRKCommentPropertiesDialogBase();

    QPushButton* buttonOk;
    QPushButton* buttonCancel;
    QGroupBox* groupBox2;
    QLabel* textLabel1_5_2;
    QSpinBox* height;
    QLabel* textLabel1_5_2_3;
    QLabel* textLabel1_5;
    QSpinBox* width;
    QLabel* textLabel1_5_4;
    QCheckBox* mirrorH;
    QCheckBox* mirrorV;
    QGroupBox* groupBox1;
    QLabel* textLabel1_4_2;
    KColorButton* textColor;
    QLabel* textLabel1;
    QSpinBox* opacity;
    QLabel* textLabel1_3;
    QLabel* textLabel1_2;
    KColorButton* fillColor;
    QGroupBox* groupBox2_2;
    QLabel* textLabel1_5_2_2;
    QSpinBox* duration;
    QLabel* textLabel1_5_2_3_2;
    QLabel* textLabel1_5_3;
    QSpinBox* startTime;
    QLabel* textLabel1_5_4_2;

protected:
    QGridLayout* SRKCommentPropertiesDialogBaseLayout;
    QHBoxLayout* layout2;
    QSpacerItem* spacer2;
    QGridLayout* groupBox2Layout;
    QHBoxLayout* layout10;
    QSpacerItem* spacer6;
    QHBoxLayout* layout9;
    QSpacerItem* spacer5;
    QHBoxLayout* layout23;
    QSpacerItem* spacer8;
    QSpacerItem* spacer10;
    QVBoxLayout* layout22;
    QGridLayout* groupBox1Layout;
    QHBoxLayout* layout8;
    QSpacerItem* spacer4;
    QHBoxLayout* layout6;
    QSpacerItem* spacer2_2;
    QHBoxLayout* layout7;
    QSpacerItem* spacer3;
    QGridLayout* groupBox2_2Layout;
    QHBoxLayout* layout16;
    QSpacerItem* spacer11_2;
    QHBoxLayout* layout25;
    QSpacerItem* spacer11;

protected slots:
    virtual void languageChange();

};

#endif // SRKCOMMENTPROPERTIESDIALOGBASE_H
