<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="screenkast" version="0.1">

<State name="fileOpened">
  <enable>
    <Action name="fileNew"/>
    <Action name="fileOpen"/>
    <Action name="fileSave"/>
    <Action name="fileSaveAs"/>
    <Action name="fileMetaInfo" />
    <Action name="fileTransmitRecording" />
    <Action name="fileExport"/>
    <Action name="fileClose"/>
    <Action name="editAddTextBalloonComment" />
    <Action name="editAddRoundedBoxComment" />
    <Action name="editAddTextBalloon2DComment" />
    <Action name="editDeleteComment" />
    <Action name="editCommentProperties" />
    <Action name="editEndCommentHere" />
  </enable>
</State>

<State name="noFileOpened">
  <enable>
    <Action name="fileNew"/>
    <Action name="fileOpen"/>
  </enable>
  <disable>
    <Action name="fileSave"/>
    <Action name="fileSaveAs"/>
    <Action name="fileMetaInfo" />
    <Action name="fileTransmitRecording" />
    <Action name="fileExport"/>
    <Action name="fileClose"/>
    <Action name="editAddTextBalloonComment" />
    <Action name="editAddRoundedBoxComment" />
    <Action name="editAddTextBalloon2DComment" />
    <Action name="editDeleteComment" />
    <Action name="editCommentProperties" />
    <Action name="editEndCommentHere" />
  </disable>
</State>

<MenuBar>

  <Menu name="File"><text>&amp;File</text>
    <Action name="fileNew" />
    <Separator />
    <Action name="fileOpen" />
    <Separator />
    <Action name="fileSave" />
    <Action name="fileSaveAs" />    
    <Separator />
    <Action name="fileMetaInfo" />
    <Action name="fileTransmitRecording" />
    <Separator />
    <Action name="fileExport" />
    <Separator />
    <Action name="fileClose" />
    <Separator />
    <Action name="fileQuit" />
  </Menu>
  
  <Menu name="Edit"><text>&amp;Edit</text>
    <Menu><text>&amp;addComment</text>
	    <Menu><text>2D</text>
		<Action name="editAddTextBalloon2DComment" />
	    </Menu>
	    
	    <Menu><text>3D</text>
	    	<Action name="editAddTextBalloonComment" />
       	    	<Action name="editAddRoundedBoxComment" />
	    </Menu>
    </Menu>
    <Action name="editDeleteComment" />
    <Separator />
    <Action name="editCommentProperties"/>
  </Menu>
  
  <Menu name="VNC"><text>&amp;VNC</text>
    <Action name="vncStartServer" />
    <Action name="vncStopServer" />
  </Menu>  
  
</MenuBar>

<Menu name="commentPopup">
  <Action name="editDeleteComment"/>
  <Action name="editCommentProperties"/>
  <Action name="editEndCommentHere" />
</Menu>
  
<Menu name="videoPopup">
	<Action name="editAddTextBalloon2DComment" />
	<Action name="editAddTextBalloonComment" />
	<Action name="editAddRoundedBoxComment" />
</Menu>

</kpartgui>
