/***************************************************************************
 *   Copyright (C) 2006 by Bram Biesbrouck                                 *
 *   b@beligum.org                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.             *
 ***************************************************************************/

#include "srkstartserverdialog.h"

SRKStartServerDialog::SRKStartServerDialog(QWidget* parent, const char* name, bool modal, WFlags fl)
    : SRKStartServerDialogBase(parent,name, modal,fl)
{
}

SRKStartServerDialog::~SRKStartServerDialog()
{
}

/*$SPECIALIZATION$*/
void SRKStartServerDialog::reject()
{
  QDialog::reject();
}

void SRKStartServerDialog::accept()
{
  QDialog::accept();
}

#include "srkstartserverdialog.moc"
