/***************************************************************************
 *   Copyright (C) 2006 by Bram Biesbrouck                                 *
 *   b@beligum.org                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.             *
 ***************************************************************************/

#ifndef SRKUTILS_H
#define SRKUTILS_H

/**
 * Utility/Helper Singleton class that provides the entire application with various routines.
 *
 * @author Bram Biesbrouck <b@beligum.org>
 */

#include <string>

#include <qobject.h>

#include "srkerror.h"

using namespace std;

class SRKUtils : public QObject
{

 public:
    /**
     * Static accesser that must be called to get/initialise an instance of this class.
     * So use ISDUtils::getInstance()-><method> to use one of the methods in this class.
     *
     * @return An instance of this class.
     */
    static SRKUtils* getInstance();

 protected:
    /**
     * Private constructor
     */
    SRKUtils();

    virtual ~SRKUtils();

 private:
    //-----VARIABLES-----
    static SRKUtils* instance;
};

#endif
