/****************************************************************************
** Form interface generated from reading ui file './srkstartserverdialogbase.ui'
**
** Created: wo sep 6 18:03:29 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.6   edited Aug 31 2005 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef STARTSERVERDIALOGBASE_H
#define STARTSERVERDIALOGBASE_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QPushButton;
class QGroupBox;
class QLabel;
class QCheckBox;
class KRestrictedLine;

class SRKStartServerDialogBase : public QDialog
{
    Q_OBJECT

public:
    SRKStartServerDialogBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~SRKStartServerDialogBase();

    QPushButton* buttonOk;
    QPushButton* buttonCancel;
    QGroupBox* groupBox;
    QLabel* textLabel2;
    QCheckBox* killOnExit;
    QLabel* vncServerDispLbl;
    QLabel* vncServerResLbl;
    KRestrictedLine* vncServerXResInput;
    KRestrictedLine* vncServerYResInput;
    QLabel* vncServerResXLbl;
    KRestrictedLine* vncServerDispInput;

protected:
    QGridLayout* StartServerDialogBaseLayout;
    QHBoxLayout* layout2;
    QSpacerItem* spacer2;
    QGridLayout* groupBoxLayout;
    QHBoxLayout* layout7;
    QSpacerItem* spacer3_2;
    QSpacerItem* spacer3;
    QVBoxLayout* layout5;
    QGridLayout* layout3;
    QSpacerItem* spacer2_2;

protected slots:
    virtual void languageChange();

};

#endif // STARTSERVERDIALOGBASE_H
