/****************************************************************************
** Form interface generated from reading ui file './srkmetainfodialogbase.ui'
**
** Created: wo sep 6 18:03:30 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.6   edited Aug 31 2005 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SRKMETAINFODIALOGBASE_H
#define SRKMETAINFODIALOGBASE_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class SRKCategoryComboBox;
class SRKPlatformComboBox;
class QPushButton;
class QGroupBox;
class QLabel;
class KLineEdit;
class KTextEdit;

class SRKMetaInfoDialogBase : public QDialog
{
    Q_OBJECT

public:
    SRKMetaInfoDialogBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~SRKMetaInfoDialogBase();

    QPushButton* buttonOk;
    QPushButton* buttonCancel;
    QGroupBox* recCategoryGrp;
    QLabel* categoryLabel;
    SRKCategoryComboBox* categoryCombo;
    QGroupBox* recGrp;
    QLabel* vncViewerVncpasswdLbl_2_3;
    KLineEdit* question;
    KTextEdit* description;
    QLabel* vncViewerVncpasswdLbl;
    QLabel* vncViewerLocLbl;
    QLabel* vncViewerVncpasswdLbl_2;
    KLineEdit* title;
    QLabel* vncViewerVncpasswdLbl_2_3_2;
    QGroupBox* recPlatformGrp;
    QLabel* platformLabel;
    SRKPlatformComboBox* platformCombo;

protected:
    QGridLayout* SRKMetaInfoDialogBaseLayout;
    QHBoxLayout* layout2;
    QSpacerItem* spacer2;
    QGridLayout* recGrpLayout;
    QSpacerItem* spacer3;
    QHBoxLayout* layout11;
    QSpacerItem* spacer4;
    QGridLayout* layout12;
    QHBoxLayout* layout8;
    QSpacerItem* spacer7_2;
    QSpacerItem* spacer7;

protected slots:
    virtual void languageChange();

    virtual void categoryChanged(const QString&, SRKCategoryComboBox*);
    virtual void platformChanged(const QString&, SRKPlatformComboBox*);


private:
    QPixmap image0;
    QPixmap image1;

};

#endif // SRKMETAINFODIALOGBASE_H
