/****************************************************************************
** Form interface generated from reading ui file './srkaddlanguagedialogbase.ui'
**
** Created: wo sep 6 18:03:30 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.6   edited Aug 31 2005 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SRKADDLANGUAGEDIALOGBASE_H
#define SRKADDLANGUAGEDIALOGBASE_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class KLanguageButton;
class QPushButton;

class SRKAddLanguageDialogBase : public QDialog
{
    Q_OBJECT

public:
    SRKAddLanguageDialogBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~SRKAddLanguageDialogBase();

    QLabel* textLabel1;
    KLanguageButton* languageCombo;
    QPushButton* buttonOk;
    QPushButton* buttonCancel;

protected:
    QVBoxLayout* SRKAddLanguageDialogBaseLayout;
    QHBoxLayout* layout4;
    QSpacerItem* spacer5;
    QSpacerItem* spacer3;
    QHBoxLayout* layout2;
    QSpacerItem* spacer2;

protected slots:
    virtual void languageChange();

};

#endif // SRKADDLANGUAGEDIALOGBASE_H
