/****************************************************************************
** Form interface generated from reading ui file './srkprefdialogbase.ui'
**
** Created: wo sep 6 18:03:29 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.6   edited Aug 31 2005 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SRKPREFDIALOGBASE_H
#define SRKPREFDIALOGBASE_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QPushButton;
class QTabWidget;
class QWidget;
class QButtonGroup;
class QGroupBox;
class QLabel;
class KLineEdit;
class KActiveLabel;
class QRadioButton;
class KRestrictedLine;
class QSpinBox;
class KColorButton;

class SRKPrefDialogBase : public QDialog
{
    Q_OBJECT

public:
    SRKPrefDialogBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~SRKPrefDialogBase();

    QPushButton* buttonOk;
    QPushButton* buttonCancel;
    QTabWidget* tabPanel;
    QWidget* Widget2;
    QButtonGroup* networkLintorialsGrp;
    QGroupBox* loginGrp;
    QLabel* textLabel3_2;
    QLabel* textLabel3;
    KLineEdit* networkLoginPasswordText;
    KLineEdit* networkLoginUsernameText;
    KActiveLabel* loginInfoLbl;
    QLabel* networkWebserviceLbl;
    KLineEdit* networkWebserviceText;
    QLabel* networkWebserviceLbl_2;
    QWidget* Widget3;
    QButtonGroup* vncServerGrp;
    QLabel* vncServerLocLbl;
    KLineEdit* vncServerLocText;
    QRadioButton* vncServerOpt1;
    QLabel* vncServerResXLbl;
    KRestrictedLine* vncServerXResText;
    QLabel* vncServerDispLbl;
    QLabel* vncServerResLbl;
    KRestrictedLine* vncServerYResText;
    KRestrictedLine* vncServerDispText1;
    QLabel* vncServerDispLbl2;
    QRadioButton* vncServerOpt2;
    KRestrictedLine* vncServerDispText2;
    KLineEdit* vncServerHostText;
    QLabel* vncServerHostLbl;
    QWidget* TabPage;
    KLineEdit* pathIsdExportText;
    QLabel* pathIsdExportLbl;
    KLineEdit* pathIsdViewerText;
    QLabel* pathIsdViewerLbl;
    QWidget* TabPage_2;
    QButtonGroup* buttonGroup3;
    QLabel* pathIsdViewerLbl_2;
    QSpinBox* defaultCommentDuration;
    QLabel* pathIsdViewerLbl_2_2;
    QSpinBox* defaultCommentOpacity;
    QLabel* pathIsdViewerLbl_2_3;
    QSpinBox* defaultCommentWidth;
    QLabel* pathIsdViewerLbl_2_4;
    QSpinBox* defaultCommentHeight;
    QLabel* textLabel1_2;
    KColorButton* defaultCommentFillColor;
    QLabel* textLabel1_2_2;
    KColorButton* defaultCommentTextColor;

protected:
    QGridLayout* SRKPrefDialogBaseLayout;
    QHBoxLayout* layout2;
    QSpacerItem* spacer2;
    QGridLayout* Widget2Layout;
    QGridLayout* networkLintorialsGrpLayout;
    QGridLayout* loginGrpLayout;
    QSpacerItem* spacer14;
    QGridLayout* layout6;
    QHBoxLayout* layout6_2;
    QHBoxLayout* layout11;
    QSpacerItem* spacer16;
    QSpacerItem* spacer16_2;
    QGridLayout* Widget3Layout;
    QGridLayout* vncServerGrpLayout;
    QHBoxLayout* layout6_3;
    QGridLayout* layout5;
    QSpacerItem* spacer5;
    QSpacerItem* spacer7;
    QSpacerItem* spacer8;
    QSpacerItem* spacer6;
    QGridLayout* layout4;
    QSpacerItem* spacer3;
    QSpacerItem* spacer2_2;
    QSpacerItem* spacer4;
    QGridLayout* TabPageLayout;
    QSpacerItem* spacer15;
    QGridLayout* layout14;
    QSpacerItem* spacer13;
    QSpacerItem* spacer13_2;
    QGridLayout* TabPageLayout_2;
    QSpacerItem* spacer15_2;
    QGridLayout* buttonGroup3Layout;
    QSpacerItem* spacer36;
    QVBoxLayout* layout25;
    QHBoxLayout* layout11_2;
    QSpacerItem* spacer13_3;
    QHBoxLayout* layout11_2_2;
    QSpacerItem* spacer13_3_3;
    QHBoxLayout* layout11_3;
    QSpacerItem* spacer13_3_4;
    QHBoxLayout* layout11_4;
    QSpacerItem* spacer13_3_5;
    QHBoxLayout* layout7;
    QSpacerItem* spacer3_2;
    QHBoxLayout* layout7_2;
    QSpacerItem* spacer3_2_2;

protected slots:
    virtual void languageChange();

};

#endif // SRKPREFDIALOGBASE_H
