/****************************************************************************
** Form interface generated from reading ui file './srktransmitrecordingdialogbase.ui'
**
** Created: wo sep 6 18:03:30 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.6   edited Aug 31 2005 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SRKTRANSMITRECORDINGDIALOGBASE_H
#define SRKTRANSMITRECORDINGDIALOGBASE_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QGroupBox;
class QLabel;
class KActiveLabel;
class QButtonGroup;
class QRadioButton;
class KURLLabel;
class KLineEdit;
class QPushButton;

class SRKTransmitRecordingDialogBase : public QDialog
{
    Q_OBJECT

public:
    SRKTransmitRecordingDialogBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~SRKTransmitRecordingDialogBase();

    QGroupBox* groupBox1;
    QLabel* pixmapLabel1;
    KActiveLabel* kActiveLabel4;
    QButtonGroup* buttonGroup1;
    QRadioButton* disagreeRadio;
    QRadioButton* agreeRadio;
    QGroupBox* loginGrp;
    QLabel* loginInfoLbl;
    KURLLabel* loginInfoUrl;
    QLabel* textLabel3_2;
    QLabel* textLabel3;
    KLineEdit* passwordText;
    KLineEdit* usernameText;
    QGroupBox* groupBox3;
    QPushButton* metaInfoButton;
    QLabel* textLabel3_3;
    QPushButton* sendButton;
    QPushButton* cancelButton;

protected:
    QGridLayout* SRKTransmitRecordingDialogBaseLayout;
    QGridLayout* groupBox1Layout;
    QHBoxLayout* layout3;
    QSpacerItem* spacer4;
    QSpacerItem* spacer3;
    QHBoxLayout* layout2;
    QSpacerItem* spacer2_2;
    QGridLayout* loginGrpLayout;
    QSpacerItem* spacer7;
    QHBoxLayout* layout10;
    QSpacerItem* spacer5_2;
    QSpacerItem* spacer5;
    QGridLayout* layout11;
    QGridLayout* groupBox3Layout;
    QHBoxLayout* layout2_2;
    QSpacerItem* spacer2;

protected slots:
    virtual void languageChange();

    virtual void disclaimerAgreeToggled(bool);
    virtual void disclaimerDisagreeToggled(bool);
    virtual void editMetaInformation();


private:
    QPixmap image0;

};

#endif // SRKTRANSMITRECORDINGDIALOGBASE_H
