/****************************************************************************
** Form interface generated from reading ui file './srkvideopanelbase.ui'
**
** Created: wo sep 6 18:03:30 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.6   edited Aug 31 2005 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SRKVIDEOPANELBASE_H
#define SRKVIDEOPANELBASE_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class SRKVideoContainer;
class QSlider;
class QPushButton;
class QLabel;

class SRKVideoPanelBase : public QWidget
{
    Q_OBJECT

public:
    SRKVideoPanelBase( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~SRKVideoPanelBase();

    SRKVideoContainer* videoContainer;
    QSlider* slider;
    QPushButton* playButton;
    QPushButton* pauseButton;
    QPushButton* stopButton;
    QLabel* positionLbl;
    QLabel* resolutionLbl;

public slots:
    virtual void play();
    virtual void pause();
    virtual void stop();

protected:
    QGridLayout* SRKVideoPanelBaseLayout;
    QHBoxLayout* layout4;
    QSpacerItem* spacer3;
    QVBoxLayout* layout3;

protected slots:
    virtual void languageChange();

    virtual void updateImage(int);
    virtual void incPosition();


private:
    QPixmap image0;

};

#endif // SRKVIDEOPANELBASE_H
